function [E,S] = kriging_estimate(Xs, beta, s, theta, C, invC, lambda, Xm)
% kriging_estimate(Xs, Ys, beta, s, theta, C, invC, lambda, Xm)
%	Computes estimates for the sample points Xm, given
%	a kriging model calibrated on the sample points Xs and
%	kriging model parameters beta, s, theta, lambda, C and
%	invC.
%
%	Note: the minimal required parameters are actually only
%	Xs, Ys and theta (and of course the points for which you
%	want the estimates Xm), but for efficiency reasons, the
%	other parameters are added as well.

	m = length(Xs);

	for j = 1:m,
		% Use a quadratic kernel to allow extrapolation
		% (mind to change this also in calibrate kriging)
		c(j) = exp(-theta * (sum((Xm - Xs(j,:)).^2)));

		% Use a linear kernel to disallow extrapolation
		% (mind to change this also in calibrate kriging)
		%c(j) = exp(-theta * (norm(Xm - Xs(j,:))));

	end

	S = s * (1 - c * invC * c' + ((1 - ones(1,m) * invC * c')^2 / (ones(1,m) * invC * ones(m,1))));
	E = beta + sum(lambda .* c);
